---
title: 환불 요청 이후 취소 금액 환급 일시
category: 결제서비스 (채널설정 및 이용안내) > 이용안내 > 결제취소/환불
seo:
  title: 환불요청 이후 취소금액 환급일시
  description: 카드, 가상계좌, 실시간 계좌이체 등의 환불요청 이후 취소금액 환급일시에 대한 안내입니다.
tags:
  - 공통
  - 결제취소-환불
pgCompanies:
  - 공통
searchTags:
  - 환불
  - 취소소요
  - 환불기간
  - 환급일자
  - 환불일자
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="취소가 시도된 이후 결제수단으로 환불금이 입금되는 환급 일시를 안내드립니다.
환급은 결제수단의 원천사(카드사, 통신사, 은행 등)에서 고객에게 직접 처리되는 점 참고 부탁드립니다." />

### **카드**

- 결제 당일 전액취소의 경우 : 당일 취소 가능
- 결제 당일 부분취소의 경우 : 3\~5영업일 후에 취소 (카드사 취소 매입 절차 필요)
- 결제 당일 이후의 전액/부분취소의 경우 : 3\~5영업일 후에 취소 (카드사 취소 매입 절차 필요)

### **가상 계좌**

- 전액/부분취소 모두 : 익 영업일 이내 환급
  - 참고사항 : PG사별 환불 특약을 맺은 후 환불 서비스 이용 가능
  - 환불시 건당 300원 과금(수수료 발생)

### **실시간 계좌이체**

- 결제 당일 취소 :  당일 환급
- 결제 당일 이후의 경우 : 익 영업일 이내 환급
  - 당일 취소 시 : 취소 수수료 없음
  - 당일 이후 취소 시 : 결제 시 발생한 수수료 반환되지 않음

### 휴대폰 소액 결제

- 환불 가능 기한 : 당월 거래건만 취소 가능 (수수료X)
- 당월 이후 거래건은 PG사측 별도 취소요청을 해야합니다.\
  (금액이 납부완료된 상태일 경우, 취소요청해도 PG사에서 취소처리가 불가하며, 자체 환불처리 해야 합니다.)
- 참고사항 : 부분취소 → 휴대폰 결제는 부분취소가 불가능합니다.
  \
  (※ 예외 : KCP는 별도 설정 후 가능 / KG이니시스 남은금액 재승인 후 이전거래 전체취소하여 부분취소가능)

### 카카오페이

- 환불 가능 기한 : 카드 1년이내 / 머니 5년이내 (수수료X)

### 네이버페이

- 환불 가능 기한 >> 결제일(0일로 정의) 기준, +1095일까지만 취소 가능 (수수료X) \
  (2023.11.29 부로, 기존 “+730일까지”에서 변경 됨)

### 페이팔

- 환불 가능 기한 : 180일 이내 (수수료X)
- 참고사항
  180일의 기준은 페이팔로 \[취소하기 버튼]은 구매자 쪽에 없기 때문에 반드시 판매자의 동의가 있어야만 취소를 구매자가 받을 수 있습니다.
  판매자가 응답이 없을 경우 구매자는 페이팔이 구매자 보호가 있기 때문에 분쟁을 접수할 수 있고 분쟁 접수할 수 있는 기한이 최대 180일이기 때문에, 최장 180일로 보시면 됩니다.
